<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_419" sourcelanguage="en">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.cc" line="+35"/>
        <source>About Transmission</source>
        <translation>Acerca de Transmission</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;big&gt;Transmission %1&lt;/big&gt;</source>
        <translation>&lt;big&gt;Transmission %1&lt;/big&gt;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>Un cliente de bittorrent rápido y fácil</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Copyright (c) The Transmission Project</source>
        <translation>Derechos de Autor (c) The Transmission Project</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>C&amp;redits</source>
        <translation>C&amp;réditos</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;License</source>
        <translation>&amp;Licencia</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cc" line="+153"/>
        <source>Torrent Properties</source>
        <translation>Propiedades del Torrent</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Peers</source>
        <translatorcomment>Colegas</translatorcomment>
        <translation>Compañeros</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tracker</source>
        <translation>Seguidor</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Files</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location line="+176"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Mezclado</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+175"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Paused</source>
        <translation>Detenido</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>%1 (Ratio: %2)</source>
        <translatorcomment>Fracción</translatorcomment>
        <translation>%1 (Proporción: %2)</translation>
    </message>
    <message>
        <location line="+66"/>
        <source>Active now</source>
        <translation>Activo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>%1 ago</source>
        <translation>hace %1</translation>
    </message>
    <message numerus="yes">
        <location line="+41"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%n pieza @ %2)</numerusform>
            <numerusform>%1 (%Ln piezas @ %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%n pieza)</numerusform>
            <numerusform>%1 (%Ln piezas)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Privado a este seguidor &apos;--&apos; DHT y PEX deshabilitado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Public torrent</source>
        <translation>Torrent público</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Created by %1</source>
        <translation>Creado por %1</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Created on %1</source>
        <translation>Creado el %1</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>N/A</source>
        <translatorcomment>No disponible</translatorcomment>
        <translation>N/D</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Created by %1 on %2</source>
        <translation>Creado por %1 el %2</translation>
    </message>
    <message>
        <location line="+121"/>
        <location line="+21"/>
        <source>Encrypted connection</source>
        <translation>Conexión cifrada</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Optimistic unchoke</source>
        <translation>Desahogo optimista</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Downloading from this peer</source>
        <translation>Descargando de este compañero</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Descargaríamos de este compañero si nos dejara</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uploading to peer</source>
        <translation>Cargando a este compañero</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Cargaríamos a este compañero si nos pidiera</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>El compañero nos desahogo, pero no estamos interesados</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Nosotros desahogamos este compañero, pero él no está interesado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Peer was discovered through DHT</source>
        <translation>Compañero encontrado a través de DHT</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>Compañero encontrado por Intercambio de Compañeros (PEX)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Peer is an incoming connection</source>
        <translation>El compañero es una conexión de entrada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Peer is connected over uTP</source>
        <translation>Compañero conectado usando uTP</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Activity</source>
        <translation>Actividad</translation>
    </message>
    <message>
        <location line="-445"/>
        <source>%1 (100%)</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 of %2 (%3%)</source>
        <translation>%1 de %2 (%3%)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <translation>%1 de %2 (%3%), %4 Sin verificar</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>%1 (%2 corrupt)</source>
        <translation>%1 (%2 corrupto)</translation>
    </message>
    <message>
        <location line="+401"/>
        <source>Have:</source>
        <translation>Tenemos:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Availability:</source>
        <translation>Disponible:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Downloaded:</source>
        <translation>Recibido:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uploaded:</source>
        <translation>Enviado:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>State:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Running time:</source>
        <translation>Tiempo transcurrido:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Remaining time:</source>
        <translation>Tiempo faltante:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Last activity:</source>
        <translation>Ultima actividad:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Error:</source>
        <translation>Mensaje de error:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Location:</source>
        <translation>Localización:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Privacy:</source>
        <translation>Privacía:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Origin:</source>
        <translation>Origen:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Comment:</source>
        <translation>Comentario:</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Add URL </source>
        <translation>Agregar URL </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add tracker announce URL:</source>
        <translation>Agregar URL de anuncio del seguidor:</translation>
    </message>
    <message>
        <location line="+8"/>
        <location line="+12"/>
        <location line="+34"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location line="-46"/>
        <location line="+46"/>
        <source>Invalid URL &quot;%1&quot;</source>
        <translation>URL inválida &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="-34"/>
        <source>Tracker already exists.</source>
        <translation>El seguidor ya existe.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Edit URL </source>
        <translation>Editar URL</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Edit tracker announce URL:</source>
        <translation>Editar URL de anuncio del seguidor:</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Honor global &amp;limits</source>
        <translation>Respetar &amp;límites globales</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Limit &amp;download speed (%1):</source>
        <translation>Limitar velocidad de &amp;descarga (%1):</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Limit &amp;upload speed (%1):</source>
        <translation>Limitar velocidad de &amp;carga (%1):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Torrent &amp;priority:</source>
        <translation>&amp;Prioridad del torrent:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding Limits</source>
        <translation>Límite para compartir</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+15"/>
        <source>Use Global Settings</source>
        <translation>Usar Configuración Global</translation>
    </message>
    <message>
        <location line="-14"/>
        <source>Seed regardless of ratio</source>
        <translation>Compartir sin importar proporción</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Dejar de compartir llegando a proporción:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Ratio:</source>
        <translation>&amp;Proporción:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seed regardless of activity</source>
        <translation>Compartir sin importar actividad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for N minutes:</source>
        <translation>Dejar de compartir si está inactivo N minutos:</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Idle:</source>
        <translation>&amp;Inactivo:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer Connections</source>
        <translation>Conexiones de compañeros</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Maximum peers:</source>
        <translation>&amp;Máximo no. de compañeros:</translation>
    </message>
    <message>
        <location line="+75"/>
        <source>Show &amp;more details</source>
        <translation>Muestra &amp;más detalles</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;backup trackers</source>
        <translation>Muestra seguidores de &amp;respaldo</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Up</source>
        <translation>Subiendo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Bajando</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
</context>
<context>
    <name>FileAdded</name>
    <message>
        <location filename="../options.cc" line="+68"/>
        <source>Error Adding Torrent</source>
        <translation>Error al añadir torrent</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../file-tree.cc" line="+169"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Mezclada</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location line="+135"/>
        <source>File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Download</source>
        <translation>Descargado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../filterbar.cc" line="+223"/>
        <location line="+157"/>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <location line="-150"/>
        <source>Active</source>
        <translation>Activos</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding</source>
        <translation>Compartiendo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Detenidos</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Finished</source>
        <translation>Terminados</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Verifying</source>
        <translation>Verificando</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Show:</source>
        <translation>Mostrar:</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../formatter.cc" line="+38"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MiB/s</source>
        <translation>MiB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GiB/s</source>
        <translation>GiB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TiB/s</source>
        <translation>TiB/s</translation>
    </message>
    <message>
        <location line="+8"/>
        <location line="+12"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+12"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+12"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+12"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+12"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+14"/>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <location line="-12"/>
        <location line="+14"/>
        <location line="+12"/>
        <source>None</source>
        <translation>Nada</translation>
    </message>
    <message numerus="yes">
        <location line="+37"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%n día</numerusform>
            <numerusform>%Ln días</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%n hora</numerusform>
            <numerusform>%Ln horas</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%n minuto</numerusform>
            <numerusform>%Ln minutos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%n segundo</numerusform>
            <numerusform>%Ln segundos</numerusform>
        </translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+7"/>
        <location line="+7"/>
        <source>%1, %2</source>
        <translation>%1, %2</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../license.cc" line="+22"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwin.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>&amp;Torrent</source>
        <translation>&amp;Torrent</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>toolBar</source>
        <translation>Barra de Herramientas</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>&amp;New...</source>
        <translation>&amp;Nuevo...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Create a new torrent</source>
        <translation>Crear un nuevo torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Properties</source>
        <translation>&amp;Propiedades</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Mostar propiedades del torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Abrir el folder del torrent</translation>
    </message>
    <message>
        <location line="-30"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location line="-133"/>
        <source>Queue</source>
        <translation>Cola</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>Abrir el archivo</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Open Fold&amp;er</source>
        <translation>Abrir la &amp;carpeta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Start</source>
        <translation>&amp;Arrancar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Arrancar el torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>Pedirle al seguidor &amp;más compañeros</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Pedir más compañeros al seguidor</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Detener el torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Verify Local Data</source>
        <translation>&amp;Verificar datos locales</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Verificar los datos locales</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Remover el torrent</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>&amp;Borrar archivos y remover</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Remover el torrent y sus archivos</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Shift+Del</source>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Start All</source>
        <translation>Arrancar &amp;Todos</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>Dete&amp;ner todos</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Select All</source>
        <translation>&amp;Seleccionar todos</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Deselect All</source>
        <translation>Seleccionar &amp;Ninguno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferencias</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Compact View</source>
        <translation>Vista &amp;Compacta</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Vista Compacta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Barra de Herramientas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>Barra de &amp;Filtros</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>Barra de &amp;Estados</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Ordenar por &amp;Actividad</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Ordenar por &amp;Edad</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Ordenar por Tiempo &amp;Restante</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Ordenar por &amp;Nombre</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Ordenar por A&amp;vance</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Ordenar por &amp;Proporción</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Ordenar por &amp;Tamaño</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Ordenar por &amp;Estado</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Ordenar por &amp;Seguidor</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>Bitácora de &amp;Mensajes</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>&amp;Estadísticas</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>&amp;Contenido</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>&amp;Invertir órden</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>&amp;Nombre</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>&amp;Archivos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>&amp;Seguidor</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Proporción Total</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Proporción Sesión</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Transferencia Total</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Transferencia Sesión</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>&amp;Ventana Principal</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>&amp;Icono en bandeja</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session...</source>
        <translation>&amp;Cambiar sesión...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Seleccionar sesión</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Set &amp;Location...</source>
        <translation>Definir &amp;localización...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>&amp;Copiar Liga-Magnética al pizarrón de recortes</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Open &amp;URL...</source>
        <translation>Abrir &amp;URL...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+U</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Donate</source>
        <translation>&amp;Donar</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>Arranca &amp;Ahora</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>Salta la cola y arranco ahora</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Top</source>
        <translation>Mover al &amp;principio</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>Mover hacia &amp;arriba</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Down</source>
        <translation>Mover hacia a&amp;bajo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move to &amp;Bottom</source>
        <translation>Mover al &amp;final</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>Ordenar por &amp;cola</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../make-dialog.cc" line="+86"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>Creando &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>¡&quot;%1&quot; Creado!</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Error: invalid announce URL &quot;%1&quot;</source>
        <translation>Error: URL para anuncio invalido &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cancelled</source>
        <translation>Cancelado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Error reading &quot;%1&quot;: %2</source>
        <translation>Error leyendo &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Error writing &quot;%1&quot;: %2</source>
        <translation>Error escribiendo &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location line="+33"/>
        <location line="+196"/>
        <source>New Torrent</source>
        <translation>Nuevo torrent</translation>
    </message>
    <message>
        <location line="-151"/>
        <source>Select File</source>
        <translation>Seleccione archivo</translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+23"/>
        <source>Select Folder</source>
        <translation>Seleccione folder</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>&lt;i&gt;No source selected&lt;i&gt;</source>
        <translation>&lt;i&gt;No se seleccionó la fuente&lt;i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%n Archivo</numerusform>
            <numerusform>%Ln Archivos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%n Pieza</numerusform>
            <numerusform>%Ln Piezas</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 en %2; %3 @ %4</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Files</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Sa&amp;ve to:</source>
        <translation>&amp;Guardar en:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Source F&amp;older:</source>
        <translation>&amp;Folder fuente:</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+14"/>
        <source>(None)</source>
        <translation>(Ninguno)</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Source &amp;File:</source>
        <translation>&amp;Archivo fuente:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Trackers:</source>
        <translation>&amp;Seguidores</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Para agregar una URL de respaldo, agreguela en la línea siguiente al URL primario.
Para agregar otro URL primario, agrueguelo después de una línea en blanco.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Co&amp;mment</source>
        <translation>Co&amp;mentario</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Private torrent</source>
        <translation>Torrent &amp;Privado</translation>
    </message>
</context>
<context>
    <name>MyApp</name>
    <message>
        <location filename="../app.cc" line="+227"/>
        <source>Transmission is a file-sharing program.  When you run a torrent, its data will be made available to others by means of upload.  You and you alone are fully responsible for exercising proper judgement and abiding by your local laws.</source>
        <translation>Transmission es un programa para compartir archivos.  Cuando activas un torrent, sus datos van a ponerse disponibles para otros.  Usted y sólo usted es completamente responsable para usar su juicio y cumplir las leyes locales.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>I &amp;Agree</source>
        <translation>Yo &amp;acepto</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Torrent Completed</source>
        <translation>Torrent completado</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Torrent Added</source>
        <translation>Torrent añadido</translation>
    </message>
</context>
<context>
    <name>Options</name>
    <message>
        <location filename="../options.cc" line="+22"/>
        <location line="+314"/>
        <source>Open Torrent</source>
        <translation>Abrir Torrent</translation>
    </message>
    <message>
        <location line="-303"/>
        <source>&amp;Torrent file:</source>
        <translation>&amp;Archivo .torrent:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Destination folder:</source>
        <translation>Folder de &amp;destino:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baja</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Torrent &amp;priority:</source>
        <translation>&amp;Prioridad del torrent:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Verify Local Data</source>
        <translation>&amp;Verificar datos locales</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Start when added</source>
        <translation>&amp;Empezar al añadir</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>M&amp;over archivo .torrent al basurero</translation>
    </message>
    <message>
        <location line="+248"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Archivos torrent (*.torrent);;Todos los archivos (*.*)</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Select Destination</source>
        <translation>Seleccione destino</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../prefs-dialog.cc" line="+175"/>
        <source>Web Client</source>
        <translation>Cliente de Web</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Open web client</source>
        <translation>&amp;Abrir cliente de Web</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Enable web client</source>
        <translation>&amp;Habilitar cliente de Web</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Listening &amp;port:</source>
        <translation>&amp;Puerto para recibir conexiones:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Use &amp;authentication</source>
        <translation>Usar a&amp;utentificación</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Username:</source>
        <translation>&amp;Nombre de usuario:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Pass&amp;word:</source>
        <translation>Cla&amp;ve de usuario:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Only allow these IP a&amp;ddresses to connect:</source>
        <translation>Sólo permitir conexiones de estas &amp;direcciones IP:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Addresses:</source>
        <translation>Direcciones:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Speed Limits</source>
        <translation>Límites de velocidad</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Limit &amp;download speed (%1):</source>
        <translation>Limite para &amp;bajada (%1):</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Limit &amp;upload speed (%1):</source>
        <translation>Límite para &amp;subida (%1):</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Temporary Speed Limits</source>
        <translation>Límites temporales de velocidad</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Ignorar límites normales de velocidad manualmente o en horarios programados&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Limit do&amp;wnload speed (%1):</source>
        <translation>Limitar velocidad de &amp;bajada (%1):</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Limit u&amp;pload speed (%1):</source>
        <translation>Limitar velocidad de &amp;subida (%1):</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Scheduled times:</source>
        <translation>&amp;Horarios programados:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;to</source>
        <translation>&amp;a</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;On days:</source>
        <translation>&amp;Días activos:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Every Day</source>
        <translation>Todos los días</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Entre semana</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Fin de semana</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Monday</source>
        <translation>Lunes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tuesday</source>
        <translation>Martes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Wednesday</source>
        <translation>Miércoles</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Thursday</source>
        <translation>Jueves</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Friday</source>
        <translation>Viernes</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+334"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location line="-332"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Mostrar ícono de Transmission en el área de &amp;notificaciones</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show &amp;popup notifications</source>
        <translation>Mostrar notificaciones por medio de &amp;popup</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Port is &lt;b&gt;open&lt;/b&gt;</source>
        <translation>El puerto está &lt;b&gt;abierto&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Port is &lt;b&gt;closed&lt;/b&gt;</source>
        <translation>El puerto está &lt;b&gt;cerrado&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Testing TCP Port...</source>
        <translation>Probando puerto TCP...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Incoming Peers</source>
        <translatorcomment>Compañeros entrando</translatorcomment>
        <translation>Conexiones de entrada</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Te&amp;st Port</source>
        <translation>P&amp;robar puerto</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+397"/>
        <source>Status unknown</source>
        <translation>Estado desconocido</translation>
    </message>
    <message>
        <location line="-389"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>&amp;Puerto para recibir conexiones:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>Seleccionar un puerto &amp;aleatoriamente cada vez que arranque Transmission</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>Usar UPnP o NAT-PMP para obtener un puerto y su mapeo de mi ruteador</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Limits</source>
        <translation>Límites</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Máximo número de compañeros por &amp;torrent:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>Máximo número de compañeros &amp;global:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable &amp;uTP for peer connections</source>
        <translation>Habilitar uTP en conexiones de compañeros</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>uTP is a tool for reducing network congestion.</source>
        <translation>uTP es una herramienta para reducir la congestión en redes.</translation>
    </message>
    <message numerus="yes">
        <location line="+28"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rules.</source>
        <translation>
            <numerusform>&lt;b&gt;¡Actualización exitosa!&lt;/b&gt;&lt;p&gt;La lista de bloqueos tiene ahora %n regla.</numerusform>
            <numerusform>&lt;b&gt;¡Actualización exitosa!&lt;/b&gt;&lt;p&gt;La lista de bloqueos tiene ahora %Ln reglas.</numerusform>
        </translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist...</source>
        <translation>&lt;b&gt;Actualizar Lista de bloqueos&lt;/b&gt;&lt;p&gt;Obteniendo nueva lista...</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Blocklist</source>
        <translation>Lista de bloqueo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Enable &amp;blocklist:</source>
        <translation>Habilitar lista de &amp;bloqueo:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Update</source>
        <translation>Act&amp;ualizar</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Enable &amp;automatic updates</source>
        <translation>Habilitar actualización &amp;automática</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+187"/>
        <source>Privacy</source>
        <translation>Privacia</translation>
    </message>
    <message>
        <location line="-184"/>
        <source>Allow encryption</source>
        <translation>Permitir cifrado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Preferir cifrado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Requerir cifrado</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Encryption mode:</source>
        <translation>&amp;Modo de cifrado:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>Usar PE&amp;X para encontrar más compañeros</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>PEX es una herramienta para intercambiar listas de compañeros con los que ya están conectados.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>Usar &amp;DHT para encontrar más compañeros</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>DHT es una herramienta para encontrar compañeros sin usar un seguidor.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>Usar Descubrimiento de Compañeros &amp;Local para encontrar más</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>LPD es una herramienta para encontrar compañeros en la red local.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Select &quot;Torrent Done&quot; Script</source>
        <translation>Seleccionar script ejecutado cuando el torrent termina descarga</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Select Incomplete Directory</source>
        <translation>Seleccionar directorio para incompletos</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Select Watch Directory</source>
        <translation>Seleccionar directorio de guardia</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Select Destination</source>
        <translation>Seleccionar destino</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Adding</source>
        <translation>Al agregar</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically &amp;add torrents from:</source>
        <translation>&amp;Agregar torrents automáticamente de:</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Show &amp;options dialog</source>
        <translation>Mostrar dialogo de &amp;opciones</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Start when added</source>
        <translation>&amp;Arrancar cuando se añada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>Mo&amp;ver archivo .torrent a la basura</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>Agregar .&amp;part al nombre de archivos incompletos</translation>
    </message>
    <message>
        <location line="-11"/>
        <source>Save to &amp;Location:</source>
        <translation>Guardar en &amp;locación:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>Mantener archivos &amp;incompletos en:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Call scrip&amp;t when torrent is completed:</source>
        <translation>Ejecutar scrip&amp;t cuando el torrent esté completo:</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Seeding Limits</source>
        <translation>Límites para compartir</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>Dejar de compartir llegando a &amp;proporción:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Stop seeding if idle for &amp;N minutes:</source>
        <translation>Dejar de compartir si está inactivo &amp;N minutos:</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Location</source>
        <translation>Localización</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Queue</source>
        <translatorcomment>Fila</translatorcomment>
        <translation>Cola</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Maximum active &amp;downloads:</source>
        <translation>Máx.&amp;descargas activas:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Downloads sharing data in the last N minutes are &amp;active:</source>
        <translation>Descargas compartiendo en los últimos N minutos se consideran &amp;activas:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Incomplete</source>
        <translation>Incompleto</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Transmission Preferences</source>
        <translation>Preferencias del programa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Torrents</source>
        <translation>Torrents</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Not supported by remote sessions</source>
        <translation>No soportado por sesiones remotas</translation>
    </message>
    <message numerus="yes">
        <location line="+31"/>
        <source>&lt;i&gt;Blocklist contains %Ln rules&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;Lista de bloqueos contiene %Ln reglas&lt;/i&gt;</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../app.cc" line="-163"/>
        <source>Invalid option</source>
        <translation>Opción inválida</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../relocate.cc" line="+51"/>
        <source>Select Location</source>
        <translation>Seleccione localización</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Set Torrent Location</source>
        <translation>Defina localización del torrent</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Set Location</source>
        <translation>Definir localización</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>New &amp;location:</source>
        <translation>Nueva &amp;localización:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Move from the current folder</source>
        <translation>&amp;Mover del directorio actual</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Local data is &amp;already there</source>
        <translation>Los datos locales &amp;ya están ahí</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../session.cc" line="+797"/>
        <source>Add Torrent</source>
        <translation>Agregar torrent</translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../session-dialog.cc" line="+71"/>
        <source>Change Session</source>
        <translation>Cambiar sesión</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start &amp;Local Session</source>
        <translation>Empezar sesión &amp;local</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>Conectar a sesión &amp;remota</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Host:</source>
        <translatorcomment>Servidor / Compu / etc.</translatorcomment>
        <translation>&amp;Anfitrión:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Port:</source>
        <translation>&amp;Puerto:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Authentication required</source>
        <translation>&amp;Autentificación requerida</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>&amp;Nombre de usuario</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pass&amp;word:</source>
        <translation>&amp;Clave de usuario:</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../stats-dialog.cc" line="+35"/>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Current Session</source>
        <translation>Sesión actual</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Uploaded:</source>
        <translation>Cargados:</translation>
    </message>
    <message>
        <location line="-6"/>
        <location line="+7"/>
        <source>Downloaded:</source>
        <translation>Descargados:</translation>
    </message>
    <message>
        <location line="-6"/>
        <location line="+7"/>
        <source>Ratio:</source>
        <translation>Proporción:</translation>
    </message>
    <message>
        <location line="-6"/>
        <location line="+7"/>
        <source>Duration:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <location line="+53"/>
        <source>Started %n time(s)</source>
        <translation>
            <numerusform>Arrancado %n vez</numerusform>
            <numerusform>Arrancado %n veces</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../torrent.cc" line="+708"/>
        <source>Verifying local data</source>
        <translation>Verificando datos locales</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Downloading</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Seeding</source>
        <translation>Compartiendo</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>Detenido</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Queued for verification</source>
        <translatorcomment>Esperando verificación</translatorcomment>
        <translation>En cola para verificación</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Queued for download</source>
        <translation>En cola para descarga</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Queued for seeding</source>
        <translation>En cola para carga</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Tracker gave a warning: %1</source>
        <translation>El seguidor dió una advertencia: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracker gave an error: %1</source>
        <translation>El seguidor dió un error: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../torrent-delegate.cc" line="+76"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <translation>Transferencia magnética - descargando metadata (%1%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <translation>%1 de %2 (%3%)</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <translation>%1 de %2 (%3%), cargado %4 (Proporción: %5 Meta: %6)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <translation>%1 de %2 (%3%), cargado %4 (Proporción: %5)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <translation>%1, cargado %2 (Proporción: %3 Meta: %4)</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <translation>%1, cargado %2 (Proporción: %3)</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+106"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message>
        <location line="-104"/>
        <source>%1 left</source>
        <translation>falta %1</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Remaining time unknown</source>
        <translation>Tiempo faltante desconocido</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>%1 %2, %3 %4</source>
        <translation>%1 %2, %3 %4</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+2"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Stalled</source>
        <translation>Atorado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Idle</source>
        <translation>Sin cambio</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Verificando datos locales (%1% probado)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Ratio: %1, </source>
        <translation>Proporción: %1, </translation>
    </message>
    <message numerus="yes">
        <location line="+33"/>
        <source>Downloading from %1 of %n connected peer(s)</source>
        <translation>
            <numerusform>Descargando desde %1 de %n compañero conectado</numerusform>
            <numerusform>Descargando desde %1 de %n compañeros conectados</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Downloading metadata from %n peer(s) (%1% done)</source>
        <translation>
            <numerusform>Descargando metadata desde %n compañero (%1% obtenido)</numerusform>
            <numerusform>Descargando metadata desde %n compañeros (%1% obtenido)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>Seeding to %1 of %n connected peer(s)</source>
        <translation>
            <numerusform>Compartiendo a %1 de %n compañero conectado</numerusform>
            <numerusform>Compartiendo a %1 de %n compañeros conectados</numerusform>
        </translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>TrMainWindow</name>
    <message>
        <location filename="../mainwin.cc" line="+446"/>
        <source>Limit Download Speed</source>
        <translation>Limitar velocidad de descarga</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+20"/>
        <source>Unlimited</source>
        <translation>Sin límite</translation>
    </message>
    <message>
        <location line="-15"/>
        <location line="+20"/>
        <location line="+502"/>
        <location line="+8"/>
        <source>Limited at %1</source>
        <translation>Limitada a %1</translation>
    </message>
    <message>
        <location line="-518"/>
        <source>Limit Upload Speed</source>
        <translation>Limitar velocidad de carga</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Dejar de compartir llegando a proporción</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seed Forever</source>
        <translatorcomment>Compartir para siempre</translatorcomment>
        <translation>Compartir sin límite</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+496"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Detener a la proporción (%1)</translation>
    </message>
    <message>
        <location line="-371"/>
        <source> - %1:%2</source>
        <translation> - %1:%2</translation>
    </message>
    <message numerus="yes">
        <location line="+11"/>
        <source>%Ln Torrent(s)</source>
        <translation>
            <numerusform>%n Torrent</numerusform>
            <numerusform>%Ln Torrents</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>%L1 of %Ln Torrent(s)</source>
        <translation>
            <numerusform>%L1 de %Ln Torrent</numerusform>
            <numerusform>%L1 de %Ln Torrents</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Idle</source>
        <translation>Sin cambio</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Transmission
Up: %1
Down: %2</source>
        <translation>Transmission
Subida: %1
Bajada: %2</translation>
    </message>
    <message>
        <location line="+20"/>
        <location line="+16"/>
        <source>Ratio: %1</source>
        <translation>Proporción: %1</translation>
    </message>
    <message>
        <location line="-11"/>
        <location line="+6"/>
        <source>Down: %1, Up: %2</source>
        <translation>Bajada: %1, Subida: %2</translation>
    </message>
    <message>
        <location line="+359"/>
        <source>Click to disable Temporary Speed Limits
(%1 down, %2 up)</source>
        <translation>Presione para deshabilitar límites temporales de velocidad
(%1 bajada, %2 subida)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
(%1 down, %2 up)</source>
        <translation>Presione para habilitar límites temporales de velocidad
(%1 bajada, %2 subida)</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Open Torrent</source>
        <translation>Abrir Torrent</translation>
    </message>
    <message>
        <location line="+36"/>
        <location line="+1"/>
        <source>Open URL or Magnet Link</source>
        <translation>Abrir URL o Liga Magnetizada</translation>
    </message>
    <message>
        <location line="+224"/>
        <source>Queue</source>
        <translation>Cola</translation>
    </message>
    <message>
        <location line="-259"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Archivos de torrent (*.torrent);;Todos los archivos (*.*)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show &amp;options dialog</source>
        <translation>Mostar diálogo de &amp;opciones</translation>
    </message>
    <message>
        <location line="+87"/>
        <source>Remove torrent?</source>
        <translation>¿Remover torrent?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Remove %1 torrents?</source>
        <translation>¿Remover %1 torrents?</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>¿Borrar archivos descargados de este torrent?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delete these %1 torrents&apos; downloaded files?</source>
        <translation>¿Borrar archivos descargados de estos %1 torrent?</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Una vez removidos, continuar la transferencia va a requerir el archivo .torrent o la liga magnética.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Una vez removidos, continuar las transferencias va a requerir los archivos .torrent o las ligas magnéticas.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>This torrent has not finished downloading.</source>
        <translation>Este torrent no ha terminado descarga.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>Estos torrent no han terminado su descarga.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>This torrent is connected to peers.</source>
        <translation>Este torrent está conectado a compañeros.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents are connected to peers.</source>
        <translation>Estos torrent están conectados a compañeros.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Uno de estos torrents está conectado a compañeros.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Algunos de estos torrents están conectados a compañeros.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Uno de estos torrents no ha teminado su descarga.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Algunos de estos torrents no han terminado su descarga.</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Transmission server is responding</source>
        <translation>El servidor Transmission está respondiendo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Last response from server was %1 ago</source>
        <translation>La última respuesta del servidor fue hace %1</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message>
        <location filename="../tracker-delegate.cc" line="+161"/>
        <source>Got a list of %1%2 peers%3 %4 ago</source>
        <translation>Recibimos una lista de %1%2 compañeros hace %3 %4</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <translation>El pedido de la lista de compañeros %1caducó hace %2 %3; se volverá a intentar</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <translation>Obtuvimos un error %1&quot;%2&quot; hace %3 %4</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>No hay actualizaciones programadas</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <translation>Pidiendo más compañeros en %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued to ask for more peers</source>
        <translation>En cola para pedir más compañeros</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers now... &lt;small&gt;%1&lt;/small&gt;</source>
        <translation>Pidiendo más compañeros ahora... &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Tracker had %1%2 seeders%3 and %4%5 leechers%6 %7 ago</source>
        <translatorcomment>.............................servidores...............parásitos</translatorcomment>
        <translation>El seguidor tenía %1%2 compartiendo%3 y %4%5 descargando hace %6 %7</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <translatorcomment>scrape == barrido ?  raspado?</translatorcomment>
        <translation>Obtuvimos un error de barrido&apos; %1&quot;%2&quot; hace %3 %4</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Asking for peer counts in %1</source>
        <translation>Pidiendo cuenta de compañeros en %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued to ask for peer counts</source>
        <translation>En cola para pedir cuenta de compañeros</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Asking for peer counts now... &lt;small&gt;%1&lt;/small&gt;</source>
        <translation>Pidiendo cuenta de compañeros ahora... &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../utils.cc" line="+47"/>
        <source>Enter a location:</source>
        <translation>Escriba una localización:</translation>
    </message>
</context>
</TS>
